<?php
/*
Plugin Name: BT - MailPoet multilingual mit Polylang
Description: MailPoet-Registrierungsformular multilingual mit Filter-Hooks und Polylang
Author: B. Thölke
Version: 1.0.0
Author URI: https://www.bt-webdesign.de/mailpoet-multilingual-mit-polylang/
*/

/*
 * MailPoet -> Einstellungen -> Registrierungsbestätigung (MailPoet -> Settings -> Sign-up Confirmation)
 * Betreff der Mail (Email subject) und Inhalt der E-Mail (Email content) können gefiltert werden
 * Beispiel Betreff beinhaltet deutschen und englischen Text:
 * [bt-mailpoet lang=en]Confirm the newsletter registration[/bt-mailpoet][bt-mailpoet lang=de]Bitte bestätigen Sie Ihre Newsletter-Registrierung[/bt-mailpoet]
 * je nachdem welche Sprache aktiv ist (pll_current_language - Polylang) wird nur der englischen bzw. deutsche Text gefiltert (Subject und Body)
 * Apply Filter in /mailpoet/lib/Subscribers/ConfirmationEmailMailer.php
 */
function bt_ml_mailpoet_signup_lang($text) {

	$lang = pll_current_language();                                               // returns 2-letters code of the current language (slug)

	if ( $lang === false ) return $text;

  switch ($lang){
    case 'de':                                                                  // alle Sprachen, die genutzt werden
    case 'en':
//  case 'fr':
//  ...
         $beginn = '[bt-mailpoet lang='.$lang.']';
         $ende = '[/bt-mailpoet]';
      	 $pos = strpos($text, $beginn);
      	 if ( $pos !== false ) {
      	      $posende = strpos($text, $ende, $pos);
      	      if ( $posende !== false ) {
                   $text = substr($text, $pos + strlen($beginn), $posende - $pos - strlen($beginn));
      	           }
             }
  }
  return $text;
}

add_filter( 'bt_select_language', 'bt_ml_mailpoet_signup_lang', 10);

/*
 * MailPoet -> Einstellungen -> Registrierungsbestätigung (MailPoet -> Settings -> Sign-up Confirmation): Bestätigungsseite (Confirmation Page)
 * Post-Id von aktiver Sprache zurückgeben (z.B. URL für Registrierungsbestätigung)
 * für jede Sprache muss die Bestätigungsseite (Confirmation Page) für die Registrierungsbestätigung angelegt und über Polylang verknüpft sein
 * Filter-Hook kann auch für andere URLs verwendet werden
 * Apply Filter in /mailpoet/lib/Subscription/SubscriptionUrlFactory.php
*/
function bt_ml_mailpoet_signup_lang_url($wp_post_id){
	return pll_get_post($wp_post_id, pll_current_language());
}

add_filter( 'bt_select_language_url', 'bt_ml_mailpoet_signup_lang_url', 10);